/************************************************************************************************

All files for ADuC7060 provided by ADI, including this file, are
provided as is without warranty of any kind, either expressed or implied.
The user assumes any and all risk from the use of this code.
It is the responsibility of the person integrating this code into an application
to ensure that the resulting application performs as required and is safe.

 Author        : ADI - Apps            www.analog.com/AduC7060

 Date          : January 2012

 File          : flash.c

 Hardware      : ADuC706x

 Description   : This Simple example program shows how to erase and sotre data in the Flash. 
                 The last page of flash is used in this example.

*************************************************************************************************/
// Bit Definitions
#define BIT0  0x01
#define BIT1  0x02
#define BIT2  0x04
#define BIT3  0x08
#define BIT4  0x10
#define BIT5  0x20
#define BIT6  0x40
#define BIT7  0x80
#define BIT8  0x100
#define BIT9  0x200
#define BIT10 0x400
#define BIT11 0x800
#define BIT12 0x1000
#define BIT13 0x2000
#define BIT14 0x4000
#define BIT15 0x8000
#define BIT16 0x10000
#define BIT22 0x400000
#define BIT30 0x40000000

#include <Analogdevices\ioaduc7060.h>
# include <intrinsics.h>

int Readdata(unsigned int add);                    // Load FEEDAT with the 16-bit data. Indexed by FEEADR
void Writedata(unsigned int add,int data);         // Write FEEDAT at the address pointed by FEEADR
void Eraseandwrite(unsigned int add,int data);     // Erase the page indexed by FEEADR and write FEEDAT at FEEADR
int Verify(unsigned int add, int data);            // Compare the contents of the location of FEEADR to the data in FEEDAT
void Erase(unsigned int add);                      // Erase the page indexed by FEEADR
void Masserase();                         // Erase 30 kB of user space
int Signature();
void Protect();
void Readprotection();                    // No JTAG read accesses for protected pages
void Writeprotection(long int pages);     // Write protection for chosen pages


int result=0;
char status=0,error=0;

int main()
{
  unsigned int i;
  FEEMOD = 0x8;				  // bit 3 should be set to allow erase/write command
  Erase(0x7600);                          // erase last page of user code (address 0x87600 to 0x877FF)
  for (i=0;i<10;i++)
  {			                  // store i. open memory window and heck data at addresses 0x87600 to 0x87612
    Writedata(0x7600+2*i, i);
  }
      
  while(1)
  {
  }
}


int Readdata(unsigned int add)
{
  int x;
  FEEDAT = 0x00;
  FEEADR = 0x80000 + add;                       
  FEECON = 0x01;                          // Load data of FEEADR in FEEDAT 
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
  x = FEEDAT;
  return x;
}

void Writedata(unsigned int add, int data)
{
  FEEDAT = data;                  
  FEEADR = 0x80000 + add;         
  FEECON = 0x02;                          // Write FEEDAT at the address FEEADR
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
}

void Eraseandwrite(unsigned int add, int data)
{
  FEEDAT = data;                  
  FEEADR = 0x80000 + add;         
  FEECON = 0x03;                        // Erase the page indexed by FEEADR and write FEEDAT
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1; 
}

int Verify(unsigned int add, int data)
{
  FEEDAT = data;                  
  FEEADR = 0x80000 + add;         
  FEECON = 0x04;                        // Compare the contents pointed by FEEADR to the data in FEEDAT
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
  return(error);
}

void Erase(unsigned int add)
{               
  FEEADR = 0x80000 + add;         
  FEECON = 0x05;                        // Erase the page indexed by FEEADR
  status = FEESTA&0x04;
}

void Masserase()
{   
  FEEMOD = FEEMOD|0x8;                  //Erase key enable	
  FEEADR = 0xFFC3;
  FEEDAT = 0x3CFF;
  FEECON = 0x06;
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
}

int Signature()
{
  FEECON= 0x0B; // Write key command
  status = FEESTA&0x03;
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
  return(FEESIG);
}

void Protect()
{
  FEEADR=0x1234; //16 bit key value
  FEEDAT=0x5678; //16 bi key value
  FEEPRO=0x8ffffffB;
  FEEMOD=0x48;
  FEECON= 0x0C; // Write key command  
  while (!(status)) status = FEESTA&0x03;
  if ((status&0x02)==0x02) error = 1;
}

void Readprotection()
{
  FEEHIDE = 0x7FFFFFFF;               // Read protection for all the Flash
}

void Writeprotection(long pages)
{
  //FEEHIDE = pages;                    // Write protection for Flash pages
  FEEPRO = pages;                    // Write protection for Flash pages
}


